====
What
====

Blogs
=====

* `WHAT IS ARTIFICIAL INTELLIGENCE? <http://www-formal.stanford.edu/jmc/whatisai/>`_ - John McCarthy
* `What is Artificial Intelligence? <http://www.ucs.louisiana.edu/~isb9112/dept/phil341/wisai/WhatisAI.html>`_ - István S. N. Berkeley Ph.D.


Books
=====

* `智能的本质 人工智能与机器人领域的64个大问题 <https://www.amazon.cn/%E5%9B%BE%E4%B9%A6/dp/B06VWZSVHK>`_, 硅谷人
  工智能专家从常识出发，与我们一起探讨奇点论、机器人伦理、智能的本质、机器人的未来、人类永生等热门人工智能话题。
  本书用大量详实的资料告诉我们，人工智能高超越人类智能的“奇点”还有很远的距离，而奇点的标志就是其是否可以自我
  繁殖、自我改进、自我进化。
* `如何创造思维 <https://book.douban.com/subject/25780470/>`_, 库兹韦尔. 这是一部洞悉未来思维模式的颠覆之
  作。库兹韦尔对于大脑和人工智能的理解，将对我们生活的方方面面，地球上的各行各异，以及我们有关未来的设想产生巨
  大的影响。库兹韦尔通过一系列推理告诉我们，我们有能力创造超越人类智能的非生物智能。创立了“库兹韦尔定律”，指出
  “技术力量正以指数规律快速发展”。同时预测：2027年电脑将在智能上超过人脑，2045年“奇点”出现——“严格生物学意
  义上的”人类将不复存在。
* `超级智能 <https://book.douban.com/subject/26308917/>`_, 尼克·波斯特洛姆.







